# gluepy

The python framework for building workflows, pipelines and DAGs designed for Data Scientists and Machine Learning Engineers.

# Get Started
```
pip install gluepy
```
# Documentation

https://gluepy.github.io/gluepy/
